export class Color extends HTMLElement {
  constructor() {
    super();
    const shadow = this.attachShadow({ mode: 'open' });
    shadow.innerHTML = `
      <div class="color">

      <p class="prop"></p>
      </div>
      <style>
        :host {
          font-family: sans-serif;
          font-size: 0.875rem;
          display: inline-flex;
          flex-direction: column;
          width: 24%;
          align-items: center;
        }
        .color {
          display: flex;
          flex-direction: column;
          height: 160px;
          width: calc(100% - 2rem);
          padding: 0 1rem;
          justify-content: center;
          align-content: center;
          font-weight: bold;
          -webkit-font-smoothing: antialiased;
          -moz-osx-font-smoothing: grayscale;
        }
        .prop {
          font-size: 0.8125rem;
          font-family: monospace;
        }
        p {
          margin: 0;
        }
      </style>
    `;
  }

  get value() {
    return this.getAttribute('value');
  }

  get prop() {
    return this.getAttribute('prop');
  }

  _checkContrast(el, value) {
    if (getContrast(value) === 'black') {
      el.style.setProperty('color', 'rgba(0,0,0,0.9)');
    } else {
      el.style.setProperty('color', 'rgba(255,255,255,0.9)');
    }
  }

  connectedCallback() {
    const inner = this.shadowRoot.querySelector('.color');
    const prop = this.shadowRoot.querySelector('.prop');
    if (this.hasAttribute('value')) {
      inner.setAttribute('style', `background-color: ${this.value};`);
      inner.insertAdjacentHTML('beforeend', `<p>${this.value}</p>`);
    }
    if (this.hasAttribute('prop')) {
      prop.insertAdjacentHTML('beforeend', `${this.prop}`);
    }
    this._checkContrast(inner, this.value);
  }
}

const getContrast = (c) => {
  c = c.replace('#', '');
  var r = parseInt(c.substr(0, 2), 16);
  var g = parseInt(c.substr(2, 2), 16);
  var b = parseInt(c.substr(4, 2), 16);
  var yiq = (r * 299 + g * 587 + b * 114) / 1000;
  return yiq >= 128 ? 'black' : 'white';
};
